"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployApp = void 0;
const lowcode_deployer_1 = require("@cloudbase/lowcode-deployer");
const lowcode_builder_1 = require("@cloudbase/lowcode-builder");
const fs_extra_1 = __importDefault(require("fs-extra"));
const common_1 = require("../../common");
const path_1 = __importDefault(require("path"));
const DEFAULT_INPUTS = {
    _inputFile: 'input.json',
    appId: 'test',
    mpAppId: '',
    buildTypeList: [lowcode_builder_1.BuildType.WEB],
    deployOptions: {
        mode: (process.env.deployMode || lowcode_builder_1.DEPLOY_MODE.PREVIEW),
    },
};
class Deoloyer {
    constructor(api, inputs) {
        this.api = api;
        this.logger = api.logger || common_1.Logger;
        let inputJSONPath = path_1.default.resolve(api.projectPath, inputs._inputFile || DEFAULT_INPUTS._inputFile);
        let params = fs_extra_1.default.existsSync(inputJSONPath) ? fs_extra_1.default.readJsonSync(inputJSONPath) : {};
        this._resolvedInputs = this.normalizInputs(api, resolveInputs(inputs, resolveInputs(params, DEFAULT_INPUTS)));
        const { appId, mpAppId, envId, buildTypeList, deployOptions, projectPath, webOptions = {} } = this._resolvedInputs;
        this.instance = new lowcode_deployer_1.deployer({
            logger: this.logger,
            type: (0, lowcode_builder_1.buildAsWebByBuildType)(buildTypeList) ? 'WEB' : 'MP',
            mode: deployOptions.mode === lowcode_builder_1.DEPLOY_MODE.UPLOAD ? lowcode_deployer_1.EDeployMode.PRODUCTION : lowcode_deployer_1.EDeployMode.PREVIEW,
            appId,
            envId,
            projectPath,
            mpAppId,
            credential: this._resolvedInputs.credential || this.api.privateSettings.credential,
            webOptions: {
                buildTypeList,
                ...webOptions,
            },
            artifactOptions: process.env.CLOUDBASE_CIID
                ? {
                    ...this._resolvedInputs.storage,
                    baseKey: `lca/${appId}/${process.env.CLOUDBASE_CIID ? `/${process.env.CLOUDBASE_CIID}` : ''}`,
                }
                : undefined,
        });
    }
    normalizInputs(api, inputs) {
        var _a;
        inputs.envId = ((_a = inputs.mainAppSerializeData.extra) === null || _a === void 0 ? void 0 : _a.envid) || inputs.envId || api.envId;
        inputs.projectPath = inputs.projectPath || api.projectPath;
        inputs.webOptions = inputs.webOptions || {};
        return inputs;
    }
    async deploy() {
        this.logger.info('👉 开始部署产物...');
        const res = await this.instance.deploy();
        this.logger.info('👉 部署成功');
        return res;
    }
}
function resolveInputs(inputs, defaultInputs) {
    return Object.assign({}, defaultInputs, inputs);
}
async function deployApp(ctx, params) {
    const instance = new Deoloyer(ctx, params);
    const res = await instance.deploy();
    return res;
}
exports.deployApp = deployApp;
