"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.watchApp = void 0;
const path_1 = require("path");
const service_1 = require("./service");
const chalk_1 = __importDefault(require("chalk"));
const os_1 = __importDefault(require("os"));
const common_1 = require("../../common");
const preview_1 = require("../preview");
const WORKSPACE = (0, path_1.resolve)(os_1.default.homedir(), 'cloudbase-lowcode/builds');
const SYNC_HISTORY_FLAG = false;
function bindRouter(koaServer, info) {
    const builder = new service_1.Builder((0, path_1.resolve)(process.cwd(), WORKSPACE), info);
    const watcher = new service_1.Watcher((0, path_1.resolve)(process.cwd(), WORKSPACE));
    koaServer.addListener('/build', async (ctx) => {
        watcher.start();
        const params = ctx.request.body;
        const result = await builder.build(ctx, params);
        const fixedResult = {
            ...result,
            ciId: result.buildId,
        };
        ctx.success(fixedResult);
    });
    koaServer.addListener('/checkStatus', async (ctx) => {
        const params = ctx.request.body;
        const fixedParams = params && {
            ...params,
            buildId: params.ciId,
        };
        const result = await builder.checkStatusInLocal(ctx, fixedParams);
        ctx.success(result);
    });
    koaServer.addListener('/ping', async (ctx) => {
        watcher.start();
        ctx.success({
            isReady: true,
            syncHistory: SYNC_HISTORY_FLAG,
        });
    });
    koaServer.addListener('/deployHistory', async (ctx) => {
        const params = ctx.request.body;
        const result = await builder.deployHistory(ctx, params);
        ctx.success(result);
    });
    koaServer.addListener('/deployHistory/detail', async (ctx) => {
        const params = ctx.request.body;
        const result = await builder.deployDetail(ctx, params);
        ctx.success(result);
    });
}
async function watchApp(info) {
    const { watchPort, wxDevtoolPath } = info;
    (0, common_1.showCliVersion)();
    const koaServer = new common_1.KoaServer({
        port: watchPort,
    });
    // 绑定构建服务
    bindRouter(koaServer, info);
    // 绑定预览服务
    const previewService = new preview_1.PreviewService({
        port: watchPort,
        wxDevtoolPath,
        mode: 'prod',
    });
    (0, preview_1.bindRouter)(koaServer, previewService);
    // 启动
    koaServer.listen();
    console.log(chalk_1.default.green('\n[微搭低代码] 成功开启本地构建模式\n'));
    // start websocket server
    const koaWSServer = new common_1.KoaWSServer();
    koaWSServer.listen(3456);
    console.log(chalk_1.default.green('\n[微搭低代码] 成功开启本地开发模式服务\n'));
}
exports.watchApp = watchApp;
