import { Logger } from '@cloudbase/toolbox';
import { LCDS } from '@cloudbase/cals';
import { IPlatformInfo } from '../gracePublish';
export declare type IPlatformType = 'web' | 'mp';
export declare const CONFIG_ENTRY_REG: RegExp;
export declare const MP_ENTRY_REG: RegExp;
export declare const MP_COMP_ENTRY_REG: RegExp;
export declare const MP_ACTION_ENTRY_REG: RegExp;
export declare const WEB_ENTRY_REG: RegExp;
export declare const WEB_COMP_ENTRY_REG: RegExp;
export declare const WEB_ACTION_ENTRY_REG: RegExp;
export declare const PUBLIC_PATH_TO_BE_SUBSITITUE: string;
export interface IBuildCompsInfo {
    name: string;
    configRoot: string;
    platformRoot: Record<IPlatformType, string> | Record<IPlatformType, IPlatformConfig>;
    context: string;
    command: 'build' | 'publish' | 'debug';
    logger: Logger;
    splitChunks?: boolean;
    sourceMap: boolean;
}
export interface IPlatformConfig {
    entry: string;
    components?: string;
    actions?: string;
}
export interface ILcdsConfig {
    schemaVersion: string;
    components: Record<string, LCDS.IComponent>;
    actions: Record<string, LCDS.IAction>;
}
export declare class GraceBuildService {
    protected info: IBuildCompsInfo;
    protected tempPath: string;
    protected outputPath: string;
    protected configEntryPath: string;
    protected mainEntryPath: string;
    protected mpMainEntryPath: string;
    protected lcdsConfigEntryPath: string;
    constructor(info: IBuildCompsInfo);
    build(): Promise<void>;
    protected clean(): Promise<void>;
    /**
     * 自动识别
     */
    protected recognition(): Promise<void>;
    /**
     * 配置识别
     */
    private configRecognition;
    /**
     * 配置识别。"configRoot": "./src/configs/" 查找根目录index，找不到，则直接找根目录components、actions
     * @param info cloudbaserc.json中的lowcodeCustomComponents
     * @returns
     */
    private getConfig;
    /**
     * 源码识别(web)
     */
    private codeRecognitionForWeb;
    /**
     * platform配置识别
        "platformRoot": {
          "web": "./src/xxx"
        }
        查找根目录index，找不到，则直接找根目录components、actions
      * @param platform 平台：web/mp
      * @param info cloudbaserc.json中的lowcodeCustomComponents
      * @returns
    */
    private getPlatformConfig;
    getPlatformEntry(platformConfig: IPlatformConfig | string): any;
    /**
     * 源码识别(mp)
     */
    private codeRecognitionForMp;
    private runWebpack;
    isTs(info: IBuildCompsInfo): boolean;
    parseWeda(platform: string, info: IBuildCompsInfo): {
        config: string;
        platform: {
            [x: string]: IPlatformConfig;
        };
    };
    /**
     * 生成package.json
     * @description
     * 旧的：web下package.json添加lowcode字段。
     * {
        "main": "./src/web/index.js",
        "lowcode": "./src/web/index.js",
       }
     * 新的：web和mp下package.json添加weda字段，main、lowcode保留。字段有区别。如下举例，mp没有components、actions
     * web：
     * {
          "main": "./src/web/index.js",
          "lowcode": "./src/web/index.js",
          "weda": {
          "config": "./src/configs/index.js",
          "platform": {
            "web": {
              "entry": "./src/web/index.js",
              "components": "./src/web/components/index.js",
              "actions": "./src/web/actions/index.js"
            }
          }
        }
        mp:
        {
          "main": "./src/web/index.js",
          "lowcode": "./src/web/index.js",
          "weda": {
          "config": "./src/configs/index.js",
          "platform": {
            "web": {
              "entry": "./src/mp/index.js"
            }
          }
        }
     *
     */
    generatePkg(platform: string, platformInfo: IPlatformInfo, codeRoot: string): Promise<void>;
    generateMpPkg(info: {
        dependencies: any;
        devDependencies: any;
        peerDependencies: any;
    }): {};
    isVersion3(platformEntry: IPlatformConfig | string): boolean;
}
export declare function graceBuildComps(info?: Omit<IBuildCompsInfo, 'logger'>): Promise<void>;
//# sourceMappingURL=index.d.ts.map