"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.graceDebugComps = void 0;
const webpack_1 = __importDefault(require("webpack"));
const graceBuild_1 = require("../graceBuild");
const common_1 = require("../../common");
const app_1 = require("../../app");
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const webpack_dev_server_1 = __importDefault(require("webpack-dev-server"));
const toolbox_1 = require("@cloudbase/toolbox");
const webpack_2 = require("../webpack");
// const DebugBaseUrl = 'https://console.cloud.tencent.com/lowcode/app/editor'
const DebugBaseUrl = 'https://lcap.cloud.tencent.com/v2/dev.html';
class GraceDebugService extends graceBuild_1.GraceBuildService {
    constructor(info) {
        super(info);
        this.debugInfo = info;
        // this.debugPage = `${DebugBaseUrl}?id=test&debugPort=${info.debugPort}&libName=${info.name}&libVersion=beta`;
        this.debugPage = `${DebugBaseUrl}?appId=test&mainAppId=test&&detailAppId=tes&source=null&debugPort=${info.debugPort}&libName=${info.name}&libVersion=beta`;
        this.debugAssetsPath = './.temp/assets';
        (0, common_1.initLowcodeCloudApiEnv)();
    }
    async debug() {
        // 清理Dist
        await this.clean();
        // 自动识别
        await this.recognition();
        // 启动DebugServer
        const koaPort = await this.runKoaDevServer();
        const config = this.createWebpackConfig();
        await this.runWebpackDevServer(config, koaPort);
    }
    async runKoaDevServer() {
        const { wxDevtoolPath, platformRoot, context, name } = this.debugInfo;
        // 创建Server
        const koaPort = await (0, toolbox_1.getPort)();
        const koaServer = new common_1.KoaServer({
            port: koaPort,
            staticPath: path_1.default.resolve(this.info.context, this.debugAssetsPath),
        });
        // 绑定预览服务
        if (platformRoot.mp && fs_extra_1.default.existsSync(path_1.default.resolve(context, this.getPlatformEntry(platformRoot.mp)))) {
            const previewService = new app_1.PreviewService({
                port: koaPort,
                wxDevtoolPath,
                mode: 'debug',
            });
            previewService.setLocalCompsPath(name, path_1.default.resolve(context, this.getPlatformEntry(platformRoot.mp)), path_1.default.resolve(context, this.debugAssetsPath));
            (0, app_1.bindRouter)(koaServer, previewService);
        }
        // 启动Server
        koaServer.listen();
        return koaPort;
    }
    async runWebpackDevServer(config, koaPort) {
        this.info.logger.info('组件库 - 启动调试服务器\n');
        const { debugPort } = this.debugInfo;
        const debugHost = '127.0.0.1';
        // 初始化参数
        const devServerOptions = {
            hot: 'only',
            host: debugHost,
            port: debugPort,
            static: {
                serveIndex: true,
                publicPath: `http://${debugHost}:${debugPort}/static/`,
            },
            headers: {
                'Access-Control-Allow-Origin': '*',
                'Access-Control-Allow-Headers': '*',
            },
            allowedHosts: 'all',
            // after: (app, server, compiler) => {
            //   openBrowser(this.debugPage)
            // },
            proxy: {
                '/api': `http://${debugHost}:${koaPort}`,
                '/assets': `http://${debugHost}:${koaPort}`,
            },
            compress: true,
            open: [this.debugPage],
        };
        // 初始化实例
        let devServer;
        devServer = new webpack_dev_server_1.default(devServerOptions, (0, webpack_1.default)(config));
        // 开启监听
        await devServer.start();
    }
    createWebpackConfig() {
        const { name, context } = this.info;
        const isTs = this.isTs(this.info);
        const service = new webpack_2.WebpackService({
            name,
            context,
            entry: {
                control: this.configEntryPath,
                main: this.mainEntryPath,
            },
            output: this.outputPath,
            mode: 'development',
            isTs,
            splitChunks: false,
            publicPath: 'http://127.0.0.1:8388/static/',
            sourceMap: false,
        });
        return service.createConfig();
    }
}
async function graceDebugComps(info) {
    const service = new GraceDebugService({ ...info, command: 'debug' });
    await service.debug();
}
exports.graceDebugComps = graceDebugComps;
